@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 1998, 2019 IBM Corp. and others
+ * Copyright (c) 1998, 2020 IBM Corp. and others
  *
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which accompanies this
@@ -83,7 +83,6 @@ public final class System {
 	private static String lineSeparator;
 		
 	private static boolean propertiesInitialized = false;
-	private static boolean useLegacyVerPresents = false; 
 
 	private static String platformEncoding;
 	private static String fileEncoding;
@@ -344,7 +343,6 @@ private static void ensureProperties(boolean isInitialization) {
 	}
 
 	lineSeparator = initializedProperties.getProperty("line.separator", "\n"); //$NON-NLS-1$
-	useLegacyVerPresents = initializedProperties.containsKey("use.legacy.version");
 
 	if (isInitialization) {
 		VM.saveAndRemoveProperties(initializedProperties);
@@ -352,6 +350,9 @@ private static void ensureProperties(boolean isInitialization) {
 
 	/* create systemProperties from properties Map */
 	systemProperties = initializedProperties;
+	
+	/* Preload system property jdk.serialFilter to prevent later modification */
+	jdk.internal.util.StaticProperty.jdkSerialFilter();
 }
 
 /* Converts a Map<String, String> to a properties object.
@@ -469,22 +470,7 @@ static Properties internalGetProperties() {
  */
 @SuppressWarnings("nls")
 public static String getProperty(String prop) {
-	String propertyString = getProperty(prop, null);
-	if (useLegacyVerPresents && prop.equals("java.version")) {
-		StackWalker walker = StackWalker.getInstance(Option.RETAIN_CLASS_REFERENCE);
-
-		/* If jdk.internal.misc.VM.initLevel() < 4, bootstrap isn't completed yet, walker.getCallerClass().getModule()
-		 * can be null, return real version in this case. 
-		 */
-		Module callerModule = walker.getCallerClass().getModule();
-		
-		if ((jdk.internal.misc.VM.initLevel() >= 4) 
-			&& ((null == callerModule) || (!callerModule.isNamed()))
-		) {
-			propertyString = "1.9.0";
-		}
-	}
-	return propertyString;
+	return getProperty(prop, null);
 }
 
 /**
